package Evo::XS;
use Evo 'Evo::Class::Attrs::XS';

our $VERSION = '0.006';    # VERSION

1;

# ABSTRACT: Evo parts written in C

__END__

=pod

=encoding UTF-8

=head1 NAME

Evo::XS - Evo parts written in C

=head1 VERSION

version 0.006

=head1 AUTHOR

alexbyk <alexbyk.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by alexbyk.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
